alias la='ls -artl'
alias ll='ls -rlt'
alias restart_isu='/etc/init.d/isu stop;/etc/init.d/xserver-nodm stop;sleep 5;killall Fiber_Optic;/etc/init.d/xserver-nodm start;sleep 5;/etc/init.d/isu start'

export TERM=linux

colorme() {
    if [[ ${EUID} == 0 ]] ; then
        export PS1='\[\033[01;31m\]\h\[\033[01;34m\] \W \$\[\033[00m\] '
    else
        export PS1='\[\033[01;32m\]\u@\h\[\033[01;34m\] \w \$\[\033[00m\] '
    fi
    alias ls='ls --color=auto'
}


export SHELLPROCESS=$(grep Name: /proc/$PPID/status | cut -f2)

# Only apply the colored prompt for SSH connections
if [ ! -e /init -a $SHELLPROCESS == "sshd"  ]
then
    colorme
fi

for f in ~/.*bash_profile
do
    if [ `basename $f` != ".bash_profile" ]
    then
        if [ -f $f ]
        then
            source $f
        fi
    fi
done

source /etc/platform.conf
